pub struct ModalitiesIdMovePostRequest {
pub asynchronous: Option<bool>,
pub level: Option<String>,
pub local_aet: Option<String>,
pub permissive: Option<bool>,
pub priority: Option<f64>,
pub resources: Option<Vec<Value>>,
pub synchronous: Option<bool>,
pub target_aet: Option<String>,
pub timeout: Option<f64>,
}Expand description
ModalitiesIdMovePostRequest :
Fields
asynchronous: Option<bool>If true, run the job in asynchronous mode, which means that the REST API call will immediately return, reporting the identifier of a job. Prefer this flavor wherever possible.
level: Option<String>Level of the query (Patient, Study, Series or Instance)
local_aet: Option<String>Local AET that is used for this commands, defaults to DicomAet configuration option. Ignored if DicomModalities already sets LocalAet for this modality.
permissive: Option<bool>If true, ignore errors during the individual steps of the job.
priority: Option<f64>In asynchronous mode, the priority of the job. The higher the value, the higher the priority.
resources: Option<Vec<Value>>List of queries identifying all the DICOM resources to be sent
synchronous: Option<bool>If true, run the job in synchronous mode, which means that the HTTP answer will directly contain the result of the job. This is the default, easy behavior, but it is not desirable for long jobs, as it might lead to network timeouts.
target_aet: Option<String>Target AET that will be used by the remote DICOM modality as a target for its C-STORE SCU commands, defaults to DicomAet configuration option in order to do a simple query/retrieve
timeout: Option<f64>Timeout for the C-MOVE command, in seconds
Implementations
Sourceimpl ModalitiesIdMovePostRequest
impl ModalitiesIdMovePostRequest
Sourcepub fn new() -> ModalitiesIdMovePostRequest
pub fn new() -> ModalitiesIdMovePostRequest