Struct ToolsBulkModifyPostRequest

pub struct ToolsBulkModifyPostRequest {
Show 15 fields pub asynchronous: Option<bool>, pub force: Option<bool>, pub keep: Option<Vec<String>>, pub keep_source: Option<bool>, pub level: Option<String>, pub lossy_quality: Option<f64>, pub permissive: Option<bool>, pub priority: Option<f64>, pub private_creator: Option<String>, pub remove: Option<Vec<String>>, pub remove_private_tags: Option<bool>, pub replace: Option<Value>, pub resources: Option<Vec<String>>, pub synchronous: Option<bool>, pub transcode: Option<String>,
}
ToolsBulkModifyPostRequest :

Fields

asynchronous: Option<bool>

If true, run the job in asynchronous mode, which means that the REST API call will immediately return, reporting the identifier of a job. Prefer this flavor wherever possible.

force: Option<bool>

Allow the modification of tags related to DICOM identifiers, at the risk of breaking the DICOM model of the real world

keep: Option<Vec<String>>

Keep the original value of the specified tags, to be chosen among the StudyInstanceUID, SeriesInstanceUID and SOPInstanceUID tags. Avoid this feature as much as possible, as this breaks the DICOM model of the real world.

keep_source: Option<bool>

If set to false, instructs Orthanc to the remove original resources. By default, the original resources are kept in Orthanc.

level: Option<String>

Level of the modification (Patient, Study, Series or Instance). If absent, the level defaults to Instance, but is set to Patient if PatientID is modified, to Study if StudyInstanceUID is modified, or to Series if SeriesInstancesUID is modified. (new in Orthanc 1.9.7)

lossy_quality: Option<f64>

If transcoding to a lossy transfer syntax, this entry defines the quality as an integer between 1 and 100. If not provided, the value is defined by the "DicomLossyTranscodingQuality" configuration. (new in v1.12.7)

permissive: Option<bool>

If true, ignore errors during the individual steps of the job.

priority: Option<f64>

In asynchronous mode, the priority of the job. The higher the value, the higher the priority.

private_creator: Option<String>

The private creator to be used for private tags in Replace

remove: Option<Vec<String>>

List of tags that must be removed from the DICOM instances. Starting with Orthanc 1.9.4, paths to subsequences can be provided using the same syntax as the dcmodify command-line tool (wildcards are supported as well).

remove_private_tags: Option<bool>

Remove the private tags from the DICOM instances (defaults to false)

replace: Option<Value>

Associative array to change the value of some DICOM tags in the DICOM instances. Starting with Orthanc 1.9.4, paths to subsequences can be provided using the same syntax as the dcmodify command-line tool (wildcards are supported as well).

resources: Option<Vec<String>>

List of the Orthanc identifiers of the patients/studies/series/instances of interest.

synchronous: Option<bool>

If true, run the job in synchronous mode, which means that the HTTP answer will directly contain the result of the job. This is the default, easy behavior, but it is not desirable for long jobs, as it might lead to network timeouts.

transcode: Option<String>

Transcode the DICOM instances to the provided DICOM transfer syntax: https://orthanc.uclouvain.be/book/faq/transcoding.html

Implementations