pub struct ModalitiesIdStorePostRequest {Show 13 fields
pub asynchronous: Option<bool>,
pub called_aet: Option<String>,
pub host: Option<String>,
pub local_aet: Option<String>,
pub move_originator_aet: Option<String>,
pub move_originator_id: Option<f64>,
pub permissive: Option<bool>,
pub port: Option<f64>,
pub priority: Option<f64>,
pub resources: Option<Vec<String>>,
pub storage_commitment: Option<bool>,
pub synchronous: Option<bool>,
pub timeout: Option<f64>,
}Expand description
ModalitiesIdStorePostRequest :
Fields
asynchronous: Option<bool>If true, run the job in asynchronous mode, which means that the REST API call will immediately return, reporting the identifier of a job. Prefer this flavor wherever possible.
called_aet: Option<String>Called AET that is used for this commands, defaults to AET configuration option. Allows you to overwrite the destination AET for a specific operation.
host: Option<String>Host that is used for this commands, defaults to Host configuration option. Allows you to overwrite the destination host for a specific operation.
local_aet: Option<String>Local AET that is used for this commands, defaults to DicomAet configuration option. Ignored if DicomModalities already sets LocalAet for this modality.
move_originator_aet: Option<String>Move originator AET that is used for this commands, in order to fake a C-MOVE SCU
move_originator_id: Option<f64>Move originator ID that is used for this commands, in order to fake a C-MOVE SCU
permissive: Option<bool>If true, ignore errors during the individual steps of the job.
port: Option<f64>Port that is used for this command, defaults to Port configuration option. Allows you to overwrite the destination port for a specific operation.
priority: Option<f64>In asynchronous mode, the priority of the job. The higher the value, the higher the priority.
resources: Option<Vec<String>>List of the Orthanc identifiers of all the DICOM resources to be sent
storage_commitment: Option<bool>Whether to chain C-STORE with DICOM storage commitment to validate the success of the transmission: https://orthanc.uclouvain.be/book/users/storage-commitment.html#chaining-c-store-with-storage-commitment
synchronous: Option<bool>If true, run the job in synchronous mode, which means that the HTTP answer will directly contain the result of the job. This is the default, easy behavior, but it is not desirable for long jobs, as it might lead to network timeouts.
timeout: Option<f64>Timeout for the C-STORE command, in seconds
Implementations
Sourceimpl ModalitiesIdStorePostRequest
impl ModalitiesIdStorePostRequest
Sourcepub fn new() -> ModalitiesIdStorePostRequest
pub fn new() -> ModalitiesIdStorePostRequest