pub struct ToolsCreateArchivePostRequest {
pub asynchronous: Option<bool>,
pub filename: Option<String>,
pub lossy_quality: Option<f64>,
pub priority: Option<f64>,
pub resources: Option<Vec<String>>,
pub synchronous: Option<bool>,
pub transcode: Option<String>,
}Expand description
ToolsCreateArchivePostRequest :
Fields
asynchronous: Option<bool>If true, create the archive in asynchronous mode, which means that a job is submitted to create the archive in background.
filename: Option<String>Filename to set in the "Content-Disposition" HTTP header (including file extension)
lossy_quality: Option<f64>If transcoding to a lossy transfer syntax, this entry defines the quality as an integer between 1 and 100. If not provided, the value is defined by the "DicomLossyTranscodingQuality" configuration. (new in v1.12.7)
priority: Option<f64>In asynchronous mode, the priority of the job. The higher the value, the higher the priority.
resources: Option<Vec<String>>The list of Orthanc identifiers of interest.
synchronous: Option<bool>If true, create the archive in synchronous mode, which means that the HTTP answer will directly contain the ZIP file. This is the default, easy behavior. However, if global configuration option "SynchronousZipStream" is set to "false", asynchronous transfers should be preferred for large amount of data, as the creation of the temporary file might lead to network timeouts.
transcode: Option<String>If present, the DICOM files in the archive will be transcoded to the provided transfer syntax: https://orthanc.uclouvain.be/book/faq/transcoding.html
Implementations